concurrency

package
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 27, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Call

func Call(ctx context.Context, fn func(ctx context.Context))

Call runs the function in a new routine.

It is useful when you want to run a function in a new routine.

func SetRecoverHook

func SetRecoverHook(fn func(ctx context.Context, err interface{}))

SetRecoverHook sets the recover hook for the routine.

Custom recover hook can be used to handle panic in routine. For example: send notification

Types

This section is empty.

Jump to